@@ -1165,14 +1165,10 @@ gsm_inhibit_dialog_init (GsmInhibitDialog *dialog)
         gtk_container_add (GTK_CONTAINER (content_area), widget);
 
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-#endif
         gtk_window_set_icon_name (GTK_WINDOW (dialog), "system-log-out");
         gtk_window_set_title (GTK_WINDOW (dialog), "");
         g_object_set (dialog,
-                      "allow-shrink", FALSE,
-                      "allow-grow", FALSE,
+                      "resizable", FALSE,
                       NULL);
 }
 
